Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CachingGitCloner ¶
type CachingGitCloner struct {
// contains filtered or unexported fields
}
CachingGitCloner implements GitCloner with local caching
func NewCachingGitCloner ¶
func NewCachingGitCloner(cacheDir string) *CachingGitCloner
NewCachingGitCloner creates a CachingGitCloner
type GitCloner ¶
type GitCloner interface {
Clone(ctx context.Context, repoURL, branch string) (repoPath string, cleanup func(), err error)
}
GitCloner defines the interface for cloning git repositories. Clone returns the path to the cloned repo and a cleanup function to call when done.
type Monitor ¶
type Monitor struct {
// contains filtered or unexported fields
}
func NewMonitor ¶
func NewMonitorWithCache ¶
NewMonitorWithCache creates a Monitor with optional caching based on config
func NewMonitorWithCloner ¶
NewMonitorWithCloner creates a Monitor with a custom GitCloner for testing
func NewMonitorWithRepos ¶
func (*Monitor) GetRecentCommits ¶
func (m *Monitor) GetRecentCommits(ctx context.Context) ([]RepoResult, error)
type RealGitCloner ¶
type RealGitCloner struct{}
RealGitCloner implements GitCloner using the git binary
Click to show internal directories.
Click to hide internal directories.